@@ -76,7 +76,7 @@ class Backend
                         '&id='.$bennoId;
         if ($scid)  $query_string .= '&scid='.$scid;
 
-        $maildata = $this->_curl_query($request_url,$query_string);
+        $maildata = $this->backend_request($request_url,$query_string);
 
         $body   = $maildata['body'];
         $header = $maildata['header'];
@@ -113,7 +113,7 @@ class Backend
                         '&format=headers';
         if ($scid)  $query_string .= '&scid='.$scid;
 
-        $header = $this->_curl_query($request_url,$query_string,'headers');
+        $header = $this->backend_request($request_url,$query_string,'headers');
 
         return $header;
     }
@@ -141,8 +141,7 @@ class Backend
             $query_string .= '&skipUTF8Recode=true';
         }
 
-        $maildata = $this->_curl_query($request_url,$query_string,'raw');
-        $result = json_decode($maildata, true);
+        $maildata = $this->backend_request($request_url,$query_string,'raw');
 
         return $maildata;
     }
@@ -169,7 +168,7 @@ class Backend
 	    if($attachmentId != "")         
 	      $query_string .= '&attachmentId='.$attachmentId;
 
-        $file = $this->_curl_query($request_url,$query_string,'raw');
+        $file = $this->backend_request($request_url,$query_string,'raw');
         if (! $file) {
             throw new Exception('NO_ATTACHMENT');
         }
@@ -189,7 +188,7 @@ class Backend
 
         $request_url  = $this->base_url.'/license/';
 
-        $data = $this->_curl_query($request_url);
+        $data = $this->backend_request($request_url);
 
         if (! $data) {
             $App->log('[Backend/fetchLicense] No valid License found');
@@ -234,7 +233,7 @@ class Backend
         $App->log("Query string: $query",3,'Backend');
         $App->log("Filter string: $this->filter",4,'Backend');
 
-        $resultList = $this->_curl_query($request_url,$query_string);
+        $resultList = $this->backend_request($request_url,$query_string);
 
         if (! preg_match('/^LICENSE_VALID/',$resultList['licenseValid'])) {
             if ($App->getConfig('USERPERMISSONS','ENABLED') != 'DISABLED') {
@@ -249,10 +248,45 @@ class Backend
     }
 
 
+    /**
+     * Backend request with fallback
+     *
+     * @param string $request_url
+     * @param string $query=false
+     * @param string $format=''
+     * @return array
+     */
+    function backend_request($request_url,$query_string=false,$format='')
+    {
+        global $App;
+        $maildata = '';
+
+        try {
+            $maildata = $this->_curl_query($request_url,$query_string,$format);
+        }
+        catch (exception $e) {  // FS#1105
+            if ($e->getMessage() == 'ERR_REST_404') {
+                $base_url_fallback = $App->getConfig('BASE_URL_FALLBACK');
+                if ($base_url_fallback) {
+                    $fallback_url = rtrim($base_url_fallback,'/').'/mail/';
+                    $App->log('Try to fetch from fallback backend: '.$fallback_url,2,'Backend');
+                    $maildata = $this->_curl_query($fallback_url,$query_string,$format);
+                }
+                else {
+                    throw new Exception('ERR_REST_404');
+                }
+            }
+        }
+
+        return $maildata;
+    }
+ 
     /**
      * Sends http query to benno2rest backend server.
      *
      * @param string $request_url
+     * @param string $query=false
+     * @param string $format=''
      * @return array
      */
     function _curl_query ($request_url,$query=false,$format='')
@@ -335,7 +369,7 @@ class Backend
     function destroy_bennorest_session()
     {
         $request_url = $this->base_url.'/logout/';
-        $this->_curl_query($request_url);
+        $this->backend_request($request_url);
     }
 
 }
