@@ -48,10 +48,7 @@ if ($archive == '') {
 }
 
 // bild path for REST request
-$req_self = $_SERVER['PHP_SELF'];      // /search/ or /mail/
-preg_match('/\/(\w+)\/?$/',$req_self,$matches);
-$rest_path = $matches[1];
-
+$rest_path = ltrim($_SERVER['PATH_INFO'],'/');
 
 // mailadress filter
 $FilterList = Filter::FetchList($USER);
